# coding=utf-8
import scrapy
from unionService.APICall import GetEvents
from scrapy.utils.project import get_project_settings


class JDUnion:
    host = ''

    apilists = {
        'spreadlink': {
            'url': '/jd/union/spreadlink',
            'params': {'url'}
        },
        'unionidPromotion': {
            'url': '/id/union/unionidPromotion',
            'params': {'url', 'coupon_url'}
        }
    }

    def __init__(self):
        settings = get_project_settings()
        self.host = settings.get('UNION_SERVICE_HOST')
        '''
        self.host = 'http://localhost:5580'
        '''

    def dict_merge(self,dict1, dict2):
        res = {**dict1, **dict2}
        return res

    def call(self, key, params):
        api = self.apilists[key]

        ret = GetEvents().apiPost(self.host + api['url'], params)

        if False == ret:
            err = 'JDUion->run 远程调用失败'
            return False

        if ret['code'] & ret['code'] != 0:
            err = 'JDuion->run (%d) %s' % (ret['code'], ret['msg'])
            return False

        return ret['data']



# -*- coding: utf-8 -*-

from urllib import request
from urllib import parse
import json
import unittest, time, re


class APICall():
    '''
    调用events记录接口
    '''

    def __init__(self):
        pass

    def apiCall(self, method, url, getparams, postparams):
        str1 = ''
        # GET方法调用
        if method == 'GET':
            if getparams != "":
                for k in getparams:
                    str1 = str1 + k + '=' + request.quote(str(getparams.get(k)))
                    if len(getparams) > 2:
                        str1 = str1 + "&"
                url = url + "&" + str1;
            result = request.urlopen(url).read()
        # POST方法调用
        if method == 'POST':
            # if postparams!="":
            data = parse.urlencode(postparams).encode("utf-8")
            req = request.Request(url, data)
            response = request.urlopen(req)
            result = response.read()
        jsdata = json.loads(result)
        return jsdata


# 单元测试继承unittest.TestCase
class GetEvents():
    def apiGet(self, base_url, params_dict):
        api = APICall()
        getparams = params_dict
        postparams = ''
        data = api.apiCall('GET', base_url, getparams, postparams)
        # # print(data)
        return data

    def apiPost(self, base_url, params_dict):
        api = APICall()
        getparams = ''
        postparams = params_dict
        # POST格式
        data = api.apiCall('POST', base_url, getparams, postparams)
        if data.get('text'):
            data = data.replace('<br>', '\n')
        # # print(data)
        return data


#!/usr/bin/env python
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: harrett
# Mail: harrett@163.com
# Created Time:  2019-08-05 17:25:34 PM
#############################################


from setuptools import setup, find_packages

setup(
    name = "unionService",
    version = "0.1.1",
    keywords = ("union", "taobao", "jd", "jingdong"),
    description = "alibaba taobao & jd union service",
    long_description = "alibaba taobao & jd union service, a part of haoyouhui project",
    license = "MIT Licence",

    url = "https://github.com/harrett/unionService.git",
    author = "harrett",
    author_email = "harrett@163.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = ['scrapy', 'furl']
)



# coding=utf-8
import scrapy
from unionService.APICall import GetEvents
from scrapy.utils.project import get_project_settings


class Dingdanxia:
    apikey = ''
    signature = False

    apilists = {
        'uland_query': {
            'url': 'http://api.tbk.dingdanxia.com/tbk/uland_query',
            'params': {'url'}
        },
        'id_privilege': {
            'url': 'http://api.tbk.dingdanxia.com/tbk/id_privilege',
            'params': {'id', 'tpwd'}
        }
    }

    def __init__(self):
        settings = get_project_settings()
        self.apikey = settings.get('DDX_TBK_KEY')
        '''
        self.apikey = 'tobereplaced'
        '''

    def dict_merge(self,dict1, dict2):
        res = {**dict1, **dict2}
        return res

    def call(self, key, params):
        api = self.apilists[key]

        params_dict = {'apikey': self.apikey}
        ret = GetEvents().apiPost(api['url'], self.dict_merge(params_dict, params))

        if False == ret:
            err = 'Dingdanxia->run 远程调用失败'
            return False

        if ret['code'] & ret['code'] != 200:
            err = 'Dingdanxia->run (%d) %s' % (ret['code'], ret['msg'])
            return False

        return ret['data']
